@@ -2,10 +2,11 @@ package MooseX::Singleton;
 
 use Moose 0.82 ();
 use Moose::Exporter;
-use MooseX::Singleton::Object;
-use MooseX::Singleton::Meta::Class;
+use MooseX::Singleton::Role::Object;
+use MooseX::Singleton::Role::Meta::Class;
+use MooseX::Singleton::Role::Meta::Instance;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 $VERSION = eval $VERSION;
 
 Moose::Exporter->setup_import_methods( also => 'Moose' );
